==> Acme-CPANModulesUtil-Bencher-0.004.tar.gz: Acme-CPANModulesUtil-Bencher-0.004/lib/Bencher/Util/CPANModules.pm <==
# no code
## no critic: TestingAndDebugging::RequireUseStrict
package Bencher::Util::CPANModules;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2021-09-06'; # DATE
our $DIST = 'Acme-CPANModulesUtil-Bencher'; # DIST
our $VERSION = '0.004'; # VERSION

1;
# ABSTRACT: Alias for Acme::CPANModulesUtil::Bencher

__END__

=pod

=encoding UTF-8

=head1 NAME

Bencher::Util::CPANModules - Alias for Acme::CPANModulesUtil::Bencher

=head1 VERSION

This document describes version 0.004 of Bencher::Util::CPANModules (from Perl distribution Acme-CPANModulesUtil-Bencher), released on 2021-09-06.

=head1 DESCRIPTION

This is an alias for L<Acme::CPANModulesUtil::Bencher> to help finding the
module easier.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Acme-CPANModulesUtil-Bencher>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Acme-CPANModulesUtil-Bencher>.

=head1 SEE ALSO

L<Acme::CPANModulesUtil::Bencher>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 CONTRIBUTING


To contribute, you can send patches by email/via RT, or send pull requests on
GitHub.

Most of the time, you don't need to build the distribution yourself. You can
simply modify the code, then test via:

 % prove -l

If you want to build the distribution (e.g. to try to install it locally on your
system), you can install L<Dist::Zilla>,
L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
beyond that are considered a bug and can be reported to me.

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2021 by perlancar <perlancar@cpan.org>.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Acme-CPANModulesUtil-Bencher>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=cut

==> Acme-CPANModulesUtil-Bencher-0.005.tar.gz: Acme-CPANModulesUtil-Bencher-0.005/lib/Bencher/Util/CPANModules.pm <==
# no code
## no critic: TestingAndDebugging::RequireUseStrict
package Bencher::Util::CPANModules;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2022-11-30'; # DATE
our $DIST = 'Acme-CPANModulesUtil-Bencher'; # DIST
our $VERSION = '0.005'; # VERSION

1;
# ABSTRACT: Alias for Acme::CPANModulesUtil::Bencher

__END__

=pod

=encoding UTF-8

=head1 NAME

Bencher::Util::CPANModules - Alias for Acme::CPANModulesUtil::Bencher

=head1 VERSION

This document describes version 0.005 of Bencher::Util::CPANModules (from Perl distribution Acme-CPANModulesUtil-Bencher), released on 2022-11-30.

=head1 DESCRIPTION

This is an alias for L<Acme::CPANModulesUtil::Bencher> to help finding the
module easier.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Acme-CPANModulesUtil-Bencher>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Acme-CPANModulesUtil-Bencher>.

=head1 SEE ALSO

L<Acme::CPANModulesUtil::Bencher>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 CONTRIBUTING


To contribute, you can send patches by email/via RT, or send pull requests on
GitHub.

Most of the time, you don't need to build the distribution yourself. You can
simply modify the code, then test via:

 % prove -l

If you want to build the distribution (e.g. to try to install it locally on your
system), you can install L<Dist::Zilla>,
L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
that are considered a bug and can be reported to me.

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2022, 2021 by perlancar <perlancar@cpan.org>.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Acme-CPANModulesUtil-Bencher>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=cut
